/*  ================================================
  ==  config_hc-05.ino - 18 Février 2016 - V 1.00   ==
 ==   Ecrit par : d.auvre (at) free (.) fr           ==
  ==  Dernière modification le : 18 février 2016    ==
    ================================================

  * !!! ATTENTION TABULATION À 2 ESPACES !!!

	* Code inspiré de : http://www.techbitar.com/modify-the-hc-05-bluetooth-module-defaults-using-at-commands.html
*/

/***  Chargement des librairie  ***/
#include <SoftwareSerial.h>

/***	Définition des variables		***/
#define KEY 9
#define COM_Debug Serial


/***  Dèclaration des pin SoftwareSerial  ***/

SoftwareSerial BT_Serial(10, 11); 																			// RX | TX
char BT_buffer[30];																											// buffer de reception bluetooth
char Debug_buffer[30];																									// buffer de reception debug

int bit = 0 ;

void setup(){

  COM_Debug.begin(38400);																								// initialisation du com debug à 38400 bauds
  COM_Debug.println(F("*** Configurateur de module HC-05 ***\n\r"));
  BT_Serial.begin(38400);																								// initialisation du com bluetooth à 38400 bauds

  pinMode(KEY, OUTPUT);  																								// pin KEY doit ètre au niveau haut pour passer en mode config
  digitalWrite(KEY, HIGH);
  delay(500);
  COM_Debug.println(F("*** Rappel des commandes AT de base ***"));
  COM_Debug.println(F(" ____________________________________________________________________________"));
  COM_Debug.println(F("| Commande_AT        | Param              | Réponse                          |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT                 |                    | OK                               | => Test communication"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+VERSION?        |                    | +VERSION: <Param>                | => <Param> : Version logiciel"));
  COM_Debug.println(F("|                    |                    | OK                               |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+RESET           |                    | OK                               | => Reset du module"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+ORGL            |                    | OK                               | => Config usine"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+NAME?           |                    | +NAME: <Param>                   | => <Param> : nom du module"));
  COM_Debug.println(F("|                    |                    | OK                               |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+ROLE?           |                    | +ROLE: <Param>                   | => <Param> 0:esclave 1:maitre 2:maitre/esclave"));
  COM_Debug.println(F("|                    |                    | OK                               |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+UART?           |                    | +UART:<Param1>,<Param2>,<Param3> | => <Param1> bauds <Param2> bit de stop <Param3> parité"));
  COM_Debug.println(F("|                    |                    | OK                               |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+PSWD?           |                    | + PSWD : <Param>                 | => <Param> Mot de passe du module"));
  COM_Debug.println(F("|                    |                    | OK                               |"));
  COM_Debug.println(F("|====================|====================|==================================|"));
  COM_Debug.println(F("| AT+NAME=<Param>    | Nom                | OK                               | => Changement de nom du module"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+ROLE=<Param>    | 0:esclave          | OK                               | => Changement de type bluetooth Maitre, esclave"));
  COM_Debug.println(F("|                    | 1:maitre           |                                  |"));
  COM_Debug.println(F("|                    | 2:maitre/esclave   |                                  |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+UART=<Param1>,  | <Param1> baud de   | OK                               | => Changement de config UART"));
  COM_Debug.println(F("| <Param2>,<Param3>  | 4800 à 1382400     |                                  |"));
  COM_Debug.println(F("|                    | <Param2> Bit stop  |                                  |"));
  COM_Debug.println(F("|                    | 0 => 1 bit         |                                  |"));
  COM_Debug.println(F("|                    | 1 => 2 bit         |                                  |"));
  COM_Debug.println(F("|                    | <Param3> Parité    |                                  |"));
  COM_Debug.println(F("|                    | 0 => none          |                                  |"));
  COM_Debug.println(F("|                    | 1 => Odd parity    |                                  |"));
  COM_Debug.println(F("|                    | 1 => Even parity   |                                  |"));
  COM_Debug.println(F("|--------------------|--------------------|----------------------------------|"));
  COM_Debug.println(F("| AT+PSWD=<Param>    | Mot de passe       | OK                               | => Changement du mot de passe"));
  COM_Debug.println(F("|____________________|____________________|__________________________________|"));

	delay(500);
  COM_Debug.println(F("\n\r***   APPUYEZ SUR LE RESET DU MODULE HC-05   ***\n\rAvant de commencer toute commande AT\n\r"));

}

void loop(){
	while (BT_Serial.available() > 0){																		// Capture de la reception bluetooth
		BT_buffer[bit] = BT_Serial.read();																	// On stocke les bit reçut
		bit++;
		delay(10);																													// On attend un peu " On n'est pas des tirans quand même"
	}
	if(bit >=1){																													// Si réception on traite l'info
    COM_Debug.println(F("\n\r               --- Réponse BT ---\n\r"));
    COM_Debug.println(BT_buffer);
    memset(BT_buffer,0,30);																							// On vide la char array
    bit = 0;																														// On remet le compteur de bit a zero
	}

	while (COM_Debug.available() > 0){																		// Capture de la reception debug
		Debug_buffer[bit] = COM_Debug.read();																// On stocke les bit reçut
		bit++;
		delay(10);
	}
	if(bit >=1){																													// Si réception on traite l'info
    COM_Debug.print(F("======================================================"));
    COM_Debug.print(F("\n\rCommande AT => "));
    COM_Debug.print(Debug_buffer);
    BT_Serial.print(Debug_buffer);
    memset(Debug_buffer,0,30);
    bit = 0;
	}
}
